@@ -48,6 +48,8 @@ class PlayerManager:
         The client that the player manager is initialized with.
     """
 
+    __slots__ = ("_players", "default_player_class", "bot", "client", "_global_player_config")
+
     _global_player_config: PlayerModel
 
     def __init__(self, lavalink: Client, player: type[Player] = Player):  # type: ignore
@@ -56,16 +58,21 @@ class PlayerManager:
 
         self.client = lavalink
         self.bot = lavalink.bot
-        self.players: dict[int, Player] = {}
+        self._players: dict[int, Player] = {}
         self.default_player_class = player
 
     def __len__(self):
-        return len(self.players)
+        return len(self._players)
 
     def __iter__(self) -> Iterator[tuple[int, Player]]:
         """Returns an iterator that yields a tuple of (guild_id, player)"""
         yield from self.players.items()
 
+    @property
+    def players(self) -> dict[int, Player]:
+        """Returns a dictionary of all players in manager."""
+        return self._players
+
     @property
     def global_config(self) -> PlayerModel:
         return self._global_player_config
@@ -139,14 +146,10 @@ class PlayerManager:
         if player := self.players.pop(guild_id, None):
             await player.save()
             await player.disconnect(requester=self.client.bot.user)
-        player_state = await self.client.player_state_db_manager.get_player(guild_id)
+        player_state = await self.client.player_state_db_manager.fetch_player(guild_id)
         if player_state:
             await self._restore_player(player_state)
 
-    def players(self) -> Iterator[Player]:
-        """Returns an iterator that yields the all :class:`Player`"""
-        yield from self.players.values()
-
     def find_all(self, predicate=None):
         """Returns a list of players that match the given predicate.
 
@@ -266,7 +269,7 @@ class PlayerManager:
             await asyncio.sleep(1)
         tasks = [
             asyncio.create_task(self._restore_player(p))
-            async for p in self.client.player_state_db_manager.get_all_players()
+            async for p in self.client.player_state_db_manager.fetch_all_players()
         ]
         await asyncio.gather(*tasks, return_exceptions=True)
         LOGGER.info("Restored %s player states", len(self.players))
